@@ -148,9 +148,10 @@ class Poset:
 
     def graphviz(self, f=None, method='auto', labels=None):
         'Graphviz representation of self (or f if given)'
-        assert method in ('labels', 'arrows', 'labels_bottom', 'arrows_bottom'), (
-            f'Unknown method "{method}"'
-        )
+        
+        methods = ('auto', 'labels', 'arrows', 'labels_bottom', 'arrows_bottom')
+        assert method in methods, f'Unknown method "{method}"'
+        
         if method=='auto' and f is not None:
             if self.is_lattice and self.f_is_lub(f):
                 method = 'arrows_bottom'
